
![CycloPhaser Example Plot](https://github.com/daniloceano/CycloPhaser/raw/master/docs/_images/test_custom.png)

# CycloPhaser

This package calculates extratropical cyclone life cycle phases from vorticity data using Python.

[![Documentation Status](https://readthedocs.org/projects/cyclophaser/badge/?version=latest)](https://cyclophaser.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/cyclophaser.svg)](https://badge.fury.io/py/cyclophaser)
[![PyPI Downloads](https://pepy.tech/badge/cyclophaser)](https://pepy.tech/project/cyclophaser)
[![CircleCI](https://circleci.com/gh/daniloceano/CycloPhaser.svg?style=shield)](https://circleci.com/gh/daniloceano/CycloPhaser)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![Python Versions](https://img.shields.io/pypi/pyversions/cyclophaser)](https://pypi.org/project/cyclophaser/)

## Installation

1. Install using pip

   ```
   pip install cyclophaser


## Documentation

For detailed documentation, visit the [CycloPhaser Documentation](https://cyclophaser.readthedocs.io/en/latest/). This includes function parameters, module descriptions, and more.

# Support and Contact

For support, feature requests, or any queries, please open an issue on the GitHub repository.

# License

This project is licensed under the GNU General Public License v3.0. You may obtain a copy of the license at https://www.gnu.org/licenses/gpl-3.0.html.

